@@ -87,7 +87,7 @@ bool CanvasPrivate::OnExpose (Canvas *canvas, GdkEventExpose *event)
 	y0 *= canvas->m_Zoom;
 	y1 *= canvas->m_Zoom;
 	if (x0 <= event->area.x + event->area.width && x1 >= event->area.x && y0 <= event->area.y + event->area.height && y1 >= event->area.y) {
-		cairo_t *cr = gdk_cairo_create (canvas->m_Widget->window);
+		cairo_t *cr = gdk_cairo_create (gtk_widget_get_window (canvas->m_Widget));
 		cairo_scale (cr, canvas->m_Zoom, canvas->m_Zoom);
 		canvas->m_Root->Draw (cr, event->area.x / canvas->m_Zoom, event->area.y / canvas->m_Zoom, (event->area.x + event->area.width) / canvas->m_Zoom, (event->area.y + event->area.height) / canvas->m_Zoom, false);
 		cairo_destroy (cr);
@@ -143,7 +143,6 @@ Canvas::Canvas (Client *client):
 {
 	m_Root = new Group (this);
 	m_Widget = GTK_WIDGET (gccv_canvas_new (this));
-	SetBackgroundColor (RGBA_WHITE);
 	g_signal_connect_swapped (G_OBJECT (m_Widget), "button-press-event", G_CALLBACK (CanvasPrivate::OnButtonPressed), this);
 	g_signal_connect_swapped (G_OBJECT (m_Widget), "button-release-event", G_CALLBACK (CanvasPrivate::OnButtonReleased), this);
 	g_signal_connect_swapped (G_OBJECT (m_Widget), "motion-notify-event", G_CALLBACK (CanvasPrivate::OnMotion), this);
