@@ -68,7 +68,8 @@ Group::~Group()
 void Group::UpdateBounds ()
 {
 	if (m_Children.empty ()) {
-		m_x0 = m_y0 = m_x1 = m_y1 = 0.;
+		m_x0 = m_y0 = G_MAXDOUBLE;
+		m_x1 = m_y1 = -G_MAXDOUBLE;
 	} else {
 		list <Item *>::const_iterator i = m_Children.begin (), end = m_Children.end ();
 		double x0, y0, x1, y1;
@@ -118,7 +119,7 @@ bool Group::Draw (cairo_t *cr, double x0, double y0, double x1, double y1, bool
 	if (m_Children.empty ())
 		return true;
 	cairo_save (cr);
-	cairo_translate (cr, m_x, m_y);
+	cairo_translate (cr, m_x, m_y);	
 	x0 -= m_x;
 	y0 -= m_y;
 	x1 -= m_x;
