@@ -37,8 +37,8 @@
 #include <gccv/circle.h>
 #include <gccv/group.h>
 #include <gccv/text.h>
+#include <gccv/text-tag.h>
 #include <gcu/element.h>
-#include <goffice/math/go-math.h>
 #include <openbabel/mol.h>
 #include <glib/gi18n-lib.h>
 #include <cstdlib>
@@ -1941,12 +1941,17 @@ void Atom::AddItem ()
 		// build the symbol geometry
 		BuildSymbolGeometry (text->GetWidth (), text->GetHeight (), text->GetAscent () - text->GetY () - view->GetCHeight ());		
 		int n = GetAttachedHydrogens ();
+		gccv::Rect ink, logical;
+		text->GetBounds (&ink, &logical);
+		m_width = (logical.x1 - logical.x0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
+		m_height = (logical.y1 - logical.y0 + 2 * theme->GetPadding ()) / theme->GetZoomFactor ();
 		if (n > 0) {
 			string hs = "H";
 			if (n > 1) {
+				char *str = g_strdup_printf ("%d", n);
+				hs += str;
+				g_free (str);
 			}
-			gccv::Rect ink, logical;
-			text->GetBounds (&ink, &logical);
 			text = new gccv::Text (group, 0., 0., this);
 			text->SetFillColor ((view->GetData ()->IsSelected (this))? SelectColor: 0);
 			text->SetPadding (theme->GetPadding ());
@@ -1954,6 +1959,12 @@ void Atom::AddItem ()
 			text->SetLineWidth (0.);
 			text->SetFontDescription (view->GetPangoFontDesc ());
 			text->SetText (hs.c_str ());
+			if (n >1) {
+				gccv::TextTag *tag = new gccv::PositionTextTag (gccv::Subscript, text->GetDefaultFontSize ());
+				tag->SetStartIndex (1);
+				tag->SetEndIndex (hs.length ());
+				text->InsertTextTag (tag);
+			}
 			text->SetLineOffset (view->GetCHeight ());
 			switch (m_HPos) {
 			case LEFT_HPOS:
@@ -2056,4 +2067,22 @@ void Atom::AddItem ()
 	m_Item = group;
 }
 
+bool Atom::HasAvailableElectrons (bool paired)
+{
+	map<string, Object*>::iterator i;
+	Electron* electron = static_cast <Electron *> (GetFirstChild (i));
+	if (paired) {
+		if (m_nlp)
+			return true;
+		while (electron) { 
+			if (electron->IsPair ())
+				return true;
+			electron = static_cast <Electron *> (GetNextChild (i));
+		}
+	} else {
+		return (electron) || (m_nlp) || (m_nlu); // TODO: take curved arrows into account
+	}
+	return false;
+}
+
 }	//	namespace gcp
