@@ -4,7 +4,7 @@
  * GChemPaint library
  * fragment.h 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,10 +27,31 @@
 
 #include "text-object.h"
 #include <gccv/item-client.h>
+#include <gccv/text-tag.h>
+
+namespace gccv {
+	class Text;
+}
 
 /*!\file*/
 namespace gcp {
 
+extern gccv::Tag ChargeTag, StoichiometryTag;
+
+class ChargeTextTag: public gccv::PositionTextTag
+{
+public:
+	ChargeTextTag (double size);
+	virtual ~ChargeTextTag ();
+};
+
+class StoichiometryTextTag: public gccv::PositionTextTag
+{
+public:
+	StoichiometryTextTag (double size);
+	virtual ~StoichiometryTextTag ();
+};
+
 class FragmentAtom;
 class Atom;
 
@@ -41,7 +62,7 @@ Represents atoms groups displayed as a string. Currntly, the string is not
 fully parsed, so that some non sense strings might be accepted. Anyway, this
 will not always be the case in the future.
 */
-class Fragment: public TextObject, public gccv::ItemClient
+class Fragment: public TextObject
 {
 public:
 /*!
@@ -66,7 +87,7 @@ Used to add a representation of the fragment in the view.
 */
 	void AddItem ();
 /*!
-Used to update the representation of the fragment in the view.
+Used to update a representation of the fragment in the view.
 */
 	void UpdateItem ();
 /*!
@@ -229,6 +250,22 @@ of the fragment.
 */
 	void Update ();
 
+	typedef enum {
+		Invalid,
+		Valid,
+		Valid2D,
+		Valid3D
+	} Validity;
+
+	typedef enum {
+		AutoMode,
+		NormalMode,
+		SubscriptMode,
+		SuperscriptMode,
+		ChargeMode,
+		StoichiometryMode
+	} FragmentMode;
+
 private:
 	bool SavePortion (xmlDocPtr xml, xmlNodePtr node, unsigned start, unsigned end) const;
 
@@ -238,6 +275,10 @@ private:
 	int m_lbearing;
 	double m_CHeight;
 	bool m_Inversable;
+
+GCU_RO_PROP (gccv::Text *, TextItem)
+GCU_RO_PROP (Validity, Valid)
+GCU_PROP (FragmentMode, Mode)
 };
 
 }	//	namespace gcp
