@@ -4,7 +4,7 @@
  * GChemPaint library
  * text-object.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,10 +24,12 @@
 
 #include "config.h"
 #include "text-object.h"
+#include "text-editor.h"
 #include "document.h"
 #include "window.h"
 #include <gcu/objprops.h>
 #include <gcu/xml-utils.h>
+#include <gccv/text.h>
 #include <cstring>
 
 using namespace gcu;
@@ -37,7 +39,7 @@ namespace gcp {
 
 extern xmlDocPtr pXmlDoc;
 
-TextObject::TextObject (TypeId Type): Object (Type)
+TextObject::TextObject (TypeId Type): Object (Type), gccv::TextClient ()
 {
 	m_x = 0.;
 	m_y = 0.;
@@ -48,9 +50,11 @@ TextObject::TextObject (TypeId Type): Object (Type)
 	m_bLoading = false;
 	m_RealSave = true;
 	m_StartSel = m_EndSel = 0;
+	m_Editor = NULL;
 }
 
-TextObject::TextObject (double x, double y, TypeId Type): Object (Type)
+TextObject::TextObject (double x, double y, TypeId Type): Object (Type),
+	gccv::TextClient ()
 {
 	m_x = x;
 	m_y = y;
@@ -60,6 +64,7 @@ TextObject::TextObject (double x, double y, TypeId Type): Object (Type)
 	m_InsertOffset = -2;
 	m_bLoading = false;
 	m_StartSel = m_EndSel = 0;
+	m_Editor = NULL;
 }
 
 TextObject::~TextObject ()
@@ -84,7 +89,19 @@ xmlNodePtr TextObject::SaveSelected ()
 
 void TextObject::LoadSelected (xmlNodePtr node)
 {
-	Load(node);
+	Load (node);
+	unsigned start = 0, end = 0;
+	char *buf = reinterpret_cast <char*> (xmlGetProp(node, (xmlChar*) "start-sel"));
+	if (buf) {
+		start = strtoul (buf, NULL, 10);
+		xmlFree (buf);
+	}
+	buf = reinterpret_cast <char*> (xmlGetProp(node, (xmlChar*) "end-sel"));
+	if (buf) {
+		end = strtoul (buf, NULL, 10);
+		xmlFree (buf);
+	}
+	reinterpret_cast <gccv::Text *> (m_Item)->SetSelectionBounds (start, end);
 	OnChanged (false);
 }
 
@@ -130,22 +147,6 @@ void TextObject::Move (double x, double y, G_GNUC_UNUSED double z)
 	m_y += y;
 }
 
-void TextObject::OnSelChanged (gccv::TextSelBounds *bounds)
-{
-	if (bounds->start <= bounds->cur) {
-		m_StartSel = bounds->start;
-		m_EndSel = bounds->cur;
-	} else {
-		m_EndSel = bounds->start;
-		m_StartSel = bounds->cur;
-	}
-	bool activate = m_EndSel > m_StartSel;
-	Document* pDoc = dynamic_cast<Document*> (GetDocument ());
-	pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Erase", activate);
-	pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Copy", activate);
-	pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Cut", activate);
-}
-
 string TextObject::GetProperty (unsigned property) const
 {
 	switch (property) {
@@ -156,4 +157,29 @@ string TextObject::GetProperty (unsigned property) const
 	}
 }
 
+void TextObject::SelectionChanged (unsigned start, unsigned cur)
+{
+	if (start <= cur) {
+		m_StartSel = start;
+		m_EndSel = cur;
+	} else {
+		m_EndSel = start;
+		m_StartSel = cur;
+	}
+	bool activate = m_EndSel > m_StartSel;
+	Document* pDoc = dynamic_cast<Document*> (GetDocument ());
+	pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Erase", activate);
+	pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Copy", activate);
+	pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Cut", activate);
+	if (m_Editor)
+		m_Editor->SelectionChanged ();
+}
+
+void TextObject::TextChanged (unsigned pos)
+{
+	OnChanged (true);
+	// call SelectionChanged after OnChanged so that we can know what was selected before the text change
+	SelectionChanged (pos, pos);
+}
+
 }	//	namespace gcp
