@@ -31,7 +31,8 @@
 #include <cmath>
 #include <string>
 
-using namespace gcu;
+namespace gcu
+{
 
 CrystalAtom::CrystalAtom(): Atom()
 {
@@ -133,7 +134,7 @@ void CrystalAtom::SetSize(double r)
 	m_Radius.scale = NULL;
 	m_Radius.spin = GCU_N_A_SPIN,
 	m_Radius.charge = 0;
-	m_Radius.value.value = 0.0;
+	m_Radius.value.value = r;
 	m_Radius.value.prec = 0;
 	m_Radius.cn = -1;
 	m_Radius.value.value = 0.0;
@@ -177,7 +178,7 @@ void CrystalAtom::NetToCartesian(double a, double b, double c, double alpha, dou
 		(dx * cos(beta) + dy * cos(alpha) + dz));
 }
 
-bool CrystalAtom::SaveNode (xmlDocPtr xml, xmlNodePtr node)
+bool CrystalAtom::SaveNode (xmlDocPtr xml, xmlNodePtr node) const
 {
 	if (!WriteRadius (xml, node, m_Radius))
 		return false;
@@ -213,3 +214,5 @@ void CrystalAtom::SetRadius(const GcuAtomicRadius& r)
 	m_Radius.cn = r.cn;	//coordination number: -1: unspecified
 	m_Radius.spin = r.spin;
 }
+
+}	//	namespace gcu
