@@ -4,7 +4,7 @@
  * Gnome Chemisty Utils
  * crystaldoc.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,6 +29,7 @@
 #include "cylinder.h"
 #include "matrix.h"
 #include "sphere.h"
+#include "vector.h"
 #include "xml-utils.h"
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
@@ -36,11 +37,6 @@
 #include <clocale>
 #include <cmath>
 #include <vector>
-#ifdef HAVE_OPENBABEL_2_2
-#	include <list>
-#else
-#	include <openbabel/math/vector3.h>
-#endif
 #include <GL/gl.h>
 #include <cstring>
 
@@ -284,7 +280,7 @@ void CrystalDoc::ParseXMLTree (xmlNode* xml)
 	Update ();
 }
 
-bool CrystalDoc::LoadNewView(xmlNodePtr node)
+bool CrystalDoc::LoadNewView(G_GNUC_UNUSED xmlNodePtr node)
 {
 	return true;
 }
@@ -590,36 +586,38 @@ void CrystalDoc::Duplicate (CrystalLine& Line)
 	}
 }
 	
-void CrystalDoc::Draw (Matrix &m)
+void CrystalDoc::Draw (Matrix const &m) const
 {
-	vector3 v, v1;
+	Vector v, v1;
 	Sphere sp (10);
 	glEnable (GL_RESCALE_NORMAL);
-	CrystalAtomList::iterator i, iend = Atoms.end ();
+	CrystalAtomList::const_iterator i, iend = Atoms.end ();
 	double red, green, blue, alpha;
-	for (i = Atoms.begin (); i != iend; i++) {
-		(*i)->GetCoords (&v.x (), &v.y (), &v.z ());
-		v = m * v;
-		(*i)->GetColor (&red, &green, &blue, &alpha);
-		glColor4d (red, green, blue, alpha) ;
-		sp.draw (v, (*i)->r ());
-	}
+	for (i = Atoms.begin (); i != iend; i++)
+		if (!(*i)->IsCleaved ()) {
+			v = (*i)->GetVector ();
+			v = m * v;
+			(*i)->GetColor (&red, &green, &blue, &alpha);
+			glColor4d (red, green, blue, alpha) ;
+			sp.draw (v, (*i)->r () * (*i)->GetEffectiveRadiusRatio ());
+		}
 	glEnable (GL_NORMALIZE);
-	CrystalLineList::iterator j, jend = Lines.end ();
+	CrystalLineList::const_iterator j, jend = Lines.end ();
 	Cylinder cyl (10);
-	for (j = Lines.begin (); j != jend; j++) {
-		v.x () = (*j)->X1 ();
-		v.y () = (*j)->Y1 ();
-		v.z () = (*j)->Z1 ();
-		v = m * v;
-		v1.x () = (*j)->X2 ();
-		v1.y () = (*j)->Y2 ();
-		v1.z () = (*j)->Z2 ();
-		v1 = m * v1;
-		(*j)->GetColor (&red, &green, &blue, &alpha);
-		glColor4d (red, green, blue, alpha) ;
-		cyl.draw (v, v1, (*j)->GetRadius ());
-	}
+	for (j = Lines.begin (); j != jend; j++)
+		if (!(*j)->IsCleaved ()) {
+			v.SetZ ((*j)->X1 ());
+			v.SetX ((*j)->Y1 ());
+			v.SetY ((*j)->Z1 ());
+			v = m * v;
+			v1.SetZ ((*j)->X2 ());
+			v1.SetX ((*j)->Y2 ());
+			v1.SetY ((*j)->Z2 ());
+			v1 = m * v1;
+			(*j)->GetColor (&red, &green, &blue, &alpha);
+			glColor4d (red, green, blue, alpha) ;
+			cyl.draw (v, v1, (*j)->GetRadius ());
+		}
 }
 
 CrystalView* CrystalDoc::CreateNewView()
@@ -642,12 +640,12 @@ CrystalCleavage* CrystalDoc::CreateNewCleavage()
 	return new CrystalCleavage();
 }
 
-const char* CrystalDoc::GetProgramId()
+const char* CrystalDoc::GetProgramId() const
 {
 	return NULL;
 }
 
-xmlDocPtr CrystalDoc::BuildXMLTree()
+xmlDocPtr CrystalDoc::BuildXMLTree () const
 {
 	gchar buf[256];
 	xmlDocPtr xml;
@@ -721,28 +719,28 @@ xmlDocPtr CrystalDoc::BuildXMLTree()
 		if (m_bFixedSize)
 			xmlNewProp (node, (xmlChar *) "fixed", (xmlChar *) "true");
 		
-		CrystalAtomList::iterator i;
+		CrystalAtomList::const_iterator i;
 		for (i = AtomDef.begin(); i != AtomDef.end(); i++)
 		{
 			node = (*i)->Save(xml);
 			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		}
 	
-		CrystalLineList::iterator j;
+		CrystalLineList::const_iterator j;
 		for (j = LineDef.begin(); j != LineDef.end(); j++)
 		{
 			node = (*j)->Save(xml);
 			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		}
 	
-		CrystalCleavageList::iterator k;
+		CrystalCleavageList::const_iterator k;
 		for (k = Cleavages.begin(); k != Cleavages.end(); k++)
 		{
 			node = (*k)->Save(xml);
 			if (node) xmlAddChild(xml->children, node); else throw (int) 0;
 		}
 		
-		list<CrystalView*>::iterator view;
+		list<CrystalView*>::const_iterator view;
 		for (view = m_Views.begin(); view != m_Views.end(); view++)
 		{
 			node = (*view)->Save(xml);
@@ -861,12 +859,12 @@ bool CrystalDoc::ImportOB (OBMol &mol)
 		catom = new CrystalAtom (radius.Z, v.x (), v.y (), v.z ());
 		if (gcu_element_get_radius (&radius)) {
 			catom->SetRadius (radius);
-			catom->SetEffectiveRadiusRatio (.25);
+			catom->SetEffectiveRadiusRatio (.4);
 		}
 		AtomDef.push_back (catom);
 		atom = mol.NextAtom (it);
 	}
-
+	LineDef.push_back (new CrystalLine (edges, 0., 0., 0., 0., 0., 0., 10., .25 , .25, .25 , 1.));
 	Update ();
 	return true;
 }
