@@ -24,17 +24,6 @@
 #include "application.h"
 #include "spectrumdoc.h"
 #include "spectrumview.h"
-#include <goffice/data/go-data-simple.h>
-#include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-plot.h>
-#include <goffice/graph/gog-series-lines.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/math/go-fft.h>
-#include <goffice/math/go-math.h>
-#include <goffice/math/go-rangefunc.h>
-#include <goffice/math/go-regression.h>
-#include <goffice/utils/go-color.h>
-#include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <cstring>
 #include <sstream>
@@ -668,8 +657,8 @@ parse_line:
 		case JCAMP_PEAK_TABLE: {
 			// in that case, add drop lines ans remove the normal line
 			GogSeries *series = m_View->GetSeries ();
-			gog_object_add_by_name (GOG_OBJECT (series), "Vertical drop lines", GOG_OBJECT (g_object_new (GOG_SERIES_LINES_TYPE, NULL)));
-			GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+			gog_object_add_by_name (GOG_OBJECT (series), "Vertical drop lines", GOG_OBJECT (g_object_new (GOG_TYPE_SERIES_LINES, NULL)));
+			GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 			style->line.dash_type = GO_LINE_NONE;
 			style->line.auto_dash = false;
 		}
@@ -1561,14 +1550,13 @@ void SpectrumDocument::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrint
 {
 	cairo_t *cr;
 	gdouble width, height;
-	GtkWidget *widget = m_View->GetWidget ();
 
 	cr = gtk_print_context_get_cairo_context (context);
 	width = gtk_print_context_get_width (context);
 	height = gtk_print_context_get_height (context);
 	int w, h; // size in points
-	w = widget->allocation.width;
-	h = widget->allocation.height;
+	w = m_View->GetWidth ();
+	h = m_View->GetHeight ();
 	switch (GetScaleType ()) {
 	case GCU_PRINT_SCALE_NONE:
 		break;
@@ -1967,7 +1955,7 @@ double (*SpectrumDocument::GetConversionFunction (SpectrumUnitType oldu, Spectru
 void SpectrumDocument::OnShowIntegral ()
 {
 	m_IntegralVisible = !m_IntegralVisible;
-	GogStyle *style;
+	GOStyle *style;
 	if (m_IntegralVisible) {
 		if (integral < 0) {
 			integral = variables.size ();
@@ -2037,15 +2025,15 @@ void SpectrumDocument::OnShowIntegral ()
 			gog_series_set_dim (v.Series, 0, godata, NULL);
 			godata = go_data_vector_val_new (v.Values, v.NbValues, NULL);
 			gog_series_set_dim (v.Series, 1, godata, NULL);
-			GogStyledObject *axis = GOG_STYLED_OBJECT (g_object_new (GOG_AXIS_TYPE, "major-tick-labeled", false, NULL));
+			GOStyledObject *axis = GO_STYLED_OBJECT (g_object_new (GOG_TYPE_AXIS, "major-tick-labeled", false, NULL));
 			GogPlot	*plot = gog_series_get_plot (v.Series);
 			GogObject *chart = GOG_OBJECT (gog_object_get_parent (GOG_OBJECT (plot)));
 			gog_object_add_by_name (chart, "Y-Axis", GOG_OBJECT (axis));
 			gog_plot_set_axis (plot, GOG_AXIS (axis));
-			style = gog_styled_object_get_style (axis);
+			style = go_styled_object_get_style (axis);
 			style->line.auto_dash = false;
 			style->line.dash_type = GO_LINE_NONE;
-			style = gog_styled_object_get_style (GOG_STYLED_OBJECT (v.Series));
+			style = go_styled_object_get_style (GO_STYLED_OBJECT (v.Series));
 			style->line.auto_dash = false;
 			style->line.auto_color = false;
 			style->line.color = RGBA_RED;
@@ -2057,13 +2045,13 @@ void SpectrumDocument::OnShowIntegral ()
 			delete [] xn[4];
 			delete [] yb;
 		} else
-			style = gog_styled_object_get_style (GOG_STYLED_OBJECT (variables[integral].Series));
+			style = go_styled_object_get_style (GO_STYLED_OBJECT (variables[integral].Series));
 		// show the series
 		style->line.dash_type = GO_LINE_SOLID;
 		gog_object_request_update (GOG_OBJECT (variables[integral].Series));
 	} else {
 		// hide the series
-		style = gog_styled_object_get_style (GOG_STYLED_OBJECT (variables[integral].Series));
+		style = go_styled_object_get_style (GO_STYLED_OBJECT (variables[integral].Series));
 		style->line.dash_type = GO_LINE_NONE;
 		gog_object_request_update (GOG_OBJECT (variables[integral].Series));
 	}
