@@ -16,15 +16,20 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <config.h>
 #include "npapi.h"
-#include "npupp.h"
+#ifdef HAVE_NPFUNCTIONS_H
+#   include "npfunctions.h"
+#else
+#   include "npupp.h"
+#endif
 #include <unistd.h>
 #include <string.h>
+#include <glib.h>
 
 static NPNetscapeFuncs mozilla_funcs;
 static int pid = 0;
@@ -47,8 +52,12 @@ typedef struct {
 } ChemPlugin;
 
 static NPError ChemNew (NPMIMEType mime_type, NPP instance,
-				 uint16 mode, uint16 argc, char *argn[], char *argv[],
-				 NPSavedData *saved)
+#ifdef HAVE_NPFUNCTIONS_H
+				 G_GNUC_UNUSED uint16_t mode, uint16_t argc, char *argn[], char *argv[],
+#else
+				 G_GNUC_UNUSED uint16 mode, uint16 argc, char *argn[], char *argv[],
+#endif
+				 G_GNUC_UNUSED NPSavedData *saved)
 {
 	ChemPlugin *plugin;
 	char buf [32];
@@ -112,7 +121,7 @@ static NPError ChemNew (NPMIMEType mime_type, NPP instance,
 	return NPERR_NO_ERROR;
 }
 
-static NPError ChemDestroy (NPP instance, NPSavedData **save)
+static NPError ChemDestroy (NPP instance, G_GNUC_UNUSED NPSavedData **save)
 {
 	ChemPlugin *plugin;
 	char buf[32];
@@ -144,8 +153,12 @@ static NPError ChemSetWindow (NPP instance, NPWindow *window)
 	return NPERR_NO_ERROR;
 }
 
-static NPError ChemNewStream (NPP instance, NPMIMEType type, NPStream *stream,
-		      NPBool seekable, uint16 *stype)
+static NPError ChemNewStream (NPP instance, G_GNUC_UNUSED NPMIMEType type, G_GNUC_UNUSED NPStream *stream,
+#ifdef HAVE_NPFUNCTIONS_H
+		      G_GNUC_UNUSED NPBool seekable, uint16_t *stype)
+#else
+		      G_GNUC_UNUSED NPBool seekable, uint16 *stype)
+#endif
 {
 	ChemPlugin *plugin;
 
@@ -161,12 +174,12 @@ static NPError ChemNewStream (NPP instance, NPMIMEType type, NPStream *stream,
 	return NPERR_NO_ERROR;
 }
 
-static void ChemPrint (NPP instance, NPPrint *platformPrint)
+static void ChemPrint (G_GNUC_UNUSED NPP instance, G_GNUC_UNUSED NPPrint *platformPrint)
 {
 // TODO: implement !!!
 }
 
-static void ChemStreamAsFile (NPP instance, NPStream *stream, const char *fname)
+static void ChemStreamAsFile (NPP instance, G_GNUC_UNUSED NPStream *stream, const char *fname)
 {
 	char buf[32];
 	write (to_pipe, "file\n", 5);
@@ -176,7 +189,7 @@ static void ChemStreamAsFile (NPP instance, NPStream *stream, const char *fname)
 	write (to_pipe, "\n", 1);
 }
 
-NPError NP_GetValue (void *future, NPPVariable variable, void *value)
+NPError NP_GetValue (G_GNUC_UNUSED void *future, NPPVariable variable, void *value)
 {
 	switch (variable) {
 	case NPPVpluginNameString:
@@ -223,15 +236,30 @@ NPError NP_Initialize(NPNetscapeFuncs *mozFuncs, NPPluginFuncs *pluginFuncs) {
 	
 	pluginFuncs->version    = (NP_VERSION_MAJOR << 8) + NP_VERSION_MINOR;
 	pluginFuncs->size       = sizeof (NPPluginFuncs);
+#ifdef HAVE_NPFUNCTIONS_H
+	pluginFuncs->newp       = (NPP_NewProcPtr)ChemNew;
+	pluginFuncs->destroy    = (NPP_DestroyProcPtr) ChemDestroy;
+	pluginFuncs->setwindow  = (NPP_SetWindowProcPtr) ChemSetWindow;
+	pluginFuncs->newstream  = (NPP_NewStreamProcPtr) ChemNewStream;
+#else
 	pluginFuncs->newp       = NewNPP_NewProc (ChemNew);
 	pluginFuncs->destroy    = NewNPP_DestroyProc (ChemDestroy);
 	pluginFuncs->setwindow  = NewNPP_SetWindowProc (ChemSetWindow);
 	pluginFuncs->newstream  = NewNPP_NewStreamProc (ChemNewStream);
+#endif
 	pluginFuncs->destroystream = NULL;
+#ifdef HAVE_NPFUNCTIONS_H
+	pluginFuncs->asfile     = (NPP_StreamAsFileProcPtr) ChemStreamAsFile;
+#else
 	pluginFuncs->asfile     = NewNPP_StreamAsFileProc (ChemStreamAsFile);
+#endif
 	pluginFuncs->writeready = NULL;
 	pluginFuncs->write      = NULL;
+#ifdef HAVE_NPFUNCTIONS_H
+	pluginFuncs->print      = (NPP_PrintProcPtr) ChemPrint;
+#else
 	pluginFuncs->print      = NewNPP_PrintProc (ChemPrint);
+#endif
 	pluginFuncs->urlnotify  = NULL;
 	pluginFuncs->event      = NULL;
 #ifdef OJI
