@@ -63,7 +63,7 @@ static void on_rotate (GtkWidget *btn, gcp::Application* App)
 		tool->Rotate (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (btn)));
 }
 
-static void on_merge (GtkWidget *btn, gcp::Application* App)
+static void on_merge (G_GNUC_UNUSED GtkWidget *btn, gcp::Application* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->Merge ();
@@ -487,7 +487,6 @@ GtkWidget *gcpSelectionTool::GetPropertyPage ()
 	w = gtk_ui_manager_get_widget (m_UIManager, "/Selection");
 	gtk_toolbar_set_style (GTK_TOOLBAR (w), GTK_TOOLBAR_ICONS);
 	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (w), false);
-	gtk_toolbar_set_tooltips (GTK_TOOLBAR (w), true);
 	gtk_box_pack_start (GTK_BOX (box), w, false, false, 0);
 	gtk_widget_show_all (box);
 	m_MergeBtn = gtk_ui_manager_get_widget (m_UIManager, "/Selection/Merge");
