@@ -4,7 +4,7 @@
  * GChemPaint text plugin
  * fragmenttool.cc 
  *
- * Copyright (C) 2003-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2003-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,7 +28,6 @@
 #include <gcp/atom.h>
 #include <gcp/bond.h>
 #include <gcp/document.h>
-#include <gcp/fragment.h>
 #include <gcp/molecule.h>
 #include <gcp/settings.h>
 #include <gcp/theme.h>
@@ -46,6 +45,9 @@ extern GtkTargetEntry const text_targets[];
 
 gcpFragmentTool::gcpFragmentTool (gcp::Application *App): gcpTextTool (App, "Fragment")
 {
+	m_ImContext = gtk_im_multicontext_new ();
+	g_signal_connect (G_OBJECT (m_ImContext), "commit",
+		G_CALLBACK (OnCommit), this);
 }
 
 gcpFragmentTool::~gcpFragmentTool ()
@@ -64,25 +66,27 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 bool gcpFragmentTool::OnClicked ()
 {
 	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != FragmentType) ||
-			(static_cast <gccv::Item *> (m_Active) != dynamic_cast <gccv::ItemClient *> (m_pObject)->GetItem ()))) {
+			(static_cast <gccv::Item *> (m_Active) != static_cast <gcp::Fragment *> (m_pObject)->GetTextItem ()))) {
 		if (!Unselect ())
 			return false;
 	}
 	gcp::Document* pDoc = m_pView->GetDoc ();
+	SetSize (m_pView->GetFontHeight ());
 	if (!m_pObject) {
 		gcp::Theme *pTheme = pDoc->GetTheme ();
-		gcp::Fragment *fragment = new gcp::Fragment (m_x0 / pTheme->GetZoomFactor (), m_y0 / pTheme->GetZoomFactor ());
-		pDoc->AddFragment (fragment);
+		m_Fragment = new gcp::Fragment (m_x0 / pTheme->GetZoomFactor (), m_y0 / pTheme->GetZoomFactor ());
+		pDoc->AddFragment (m_Fragment);
 		pDoc->AbortOperation ();
 		pDoc->EmptyTranslationTable ();
-		m_pObject = fragment;
+		m_pObject = m_Fragment;
+	} else {
+		m_Fragment = NULL;
 	}
-	gccv::TextSelBounds bounds;
-	bool need_update = false;
-	gcp::Fragment *pFragment = NULL;
+/*	gccv::TextSelBounds bounds;
+	bool need_update = false;*/
 	if (m_pObject) {
-		switch(m_pObject->GetType ()) {
-			case AtomType: {
+		switch (m_pObject->GetType ()) {
+/*			case AtomType: {
 				gcp::Atom* pAtom = (gcp::Atom*) m_pObject;
 				if (pAtom->GetTotalBondsNumber () > 1)
 					return false;
@@ -121,9 +125,9 @@ bool gcpFragmentTool::OnClicked ()
 						buf = g_strdup ("H");
 					bounds.start = bounds.cur = ((pAtom->GetBestSide ())? strlen (pAtom->GetSymbol ()): 0);
 					pFragment->OnSelChanged (&bounds);
-/*					gcp_pango_layout_replace_text (pFragment->GetLayout (),
+					gcp_pango_layout_replace_text (pFragment->GetLayout (),
 						bounds.cur,
-						0, buf, pDoc->GetPangoAttrList ());*/
+						0, buf, pDoc->GetPangoAttrList ());
 					bounds.cur +=  strlen (buf);
 					need_update = true;
 					g_free (buf);
@@ -139,7 +143,7 @@ bool gcpFragmentTool::OnClicked ()
 				pDoc->EmptyTranslationTable ();
 				m_pObject = pFragment;
 				break;
-			}
+			}*/
 			case BondType:
 				return false;
 			case FragmentType:
@@ -147,19 +151,24 @@ bool gcpFragmentTool::OnClicked ()
 			default:
 				return false;
 		}
-//		m_pObject->SetSelected (gcp::SelStateUpdating);
-//		m_Active = GNOME_CANVAS_PANGO (g_object_get_data (G_OBJECT (m_pData->Items[m_pObject]), "fragment"));
-		if (need_update) {
-//			gnome_canvas_pango_set_selection_bounds (m_Active,  bounds.cur,  bounds.cur);
-			pFragment->AnalContent ((unsigned) bounds.start, (unsigned&) bounds.cur);
+		if (!m_Fragment)
+			m_Fragment = static_cast <gcp::Fragment *> (m_pObject);
+		m_Fragment->SetSelected (gcp::SelStateUpdating);
+		m_Active = m_Fragment->GetTextItem ();
+/*		if (need_update) {
+			m_Active->SetSelectionBounds (m_Active,  cur,  cur);
+			pFragment->AnalContent (start, cur);
 			pFragment->OnChanged (false);
-		}
+		}*/
 		m_pView->SetTextActive (m_Active);
-		g_object_set (G_OBJECT (m_Active), "editing", true, NULL);
-		m_CurNode = ((gcp::Fragment*) m_pObject)->SaveSelected ();
-		m_InitNode = ((gcp::Fragment*) m_pObject)->SaveSelected ();
+		m_Active->SetEditing (true);
+		m_Active->OnButtonPressed (m_x0, m_y0);
+		m_CurNode = m_Fragment->SaveSelected ();
+		m_InitNode = m_Fragment->SaveSelected ();
 		pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", false);
+		m_Fragment->SetEditor (this);
 	}
+	BuildTagsList ();
 	return true;
 }
 
@@ -174,56 +183,78 @@ void gcpFragmentTool::Activate ()
 {
 }
 
-bool gcpFragmentTool::OnEvent (GdkEvent* event)
+bool gcpFragmentTool::OnKeyPress (GdkEventKey *event)
 {
 	if (m_Active) {
-		if ((event->type == GDK_KEY_PRESS) || (event->type == GDK_KEY_RELEASE)) {
-			if (event->key.state & GDK_CONTROL_MASK) {
-				switch(event->key.keyval) {
-					case GDK_Right:
-					case GDK_Left:
-					case GDK_Up:
-					case GDK_Down:
-					case GDK_End:
-					case GDK_Home:
-					case GDK_Delete:
-					case GDK_KP_Delete:
-					case GDK_BackSpace:
+		if (event->state & GDK_CONTROL_MASK) {
+			switch(event->keyval) {
+				case GDK_Right:
+				case GDK_Left:
+				case GDK_Up:
+				case GDK_Down:
+				case GDK_End:
+				case GDK_Home:
+				case GDK_Delete:
+				case GDK_KP_Delete:
+				case GDK_BackSpace:
+					break;
+				case GDK_KP_Add:
+				case GDK_plus:
+					// enter/quit charge mode
+					m_CurMode = (m_CurMode == gcp::Fragment::ChargeMode)? gcp::Fragment::AutoMode: gcp::Fragment::ChargeMode;
+					m_Fragment->SetMode (m_CurMode);
+					BuildTagsList ();
+					break;
+				case GDK_underscore:
+					// enter/quit subscript (not stoichiometric) mode
+					m_CurMode = (m_CurMode == gcp::Fragment::SubscriptMode)? gcp::Fragment::AutoMode: gcp::Fragment::SubscriptMode;
+					m_Fragment->SetMode (m_CurMode);
+					BuildTagsList ();
+					break;
+				case GDK_dead_circumflex:
+					// enter/quit superscript (not charge) mode
+					m_CurMode = (m_CurMode == gcp::Fragment::SuperscriptMode)? gcp::Fragment::AutoMode: gcp::Fragment::SuperscriptMode;
+					m_Fragment->SetMode (m_CurMode);
+					BuildTagsList ();
+					break;
+				case GDK_n:
+					// enter/quit stoichiometry mode
+					m_CurMode = (m_CurMode == gcp::Fragment::StoichiometryMode)? gcp::Fragment::AutoMode: gcp::Fragment::StoichiometryMode;
+					m_Fragment->SetMode (m_CurMode);
+					BuildTagsList ();
+					break;
+				case GDK_space:
+					// back to auto mode
+					m_CurMode = gcp::Fragment::AutoMode;
+					m_Fragment->SetMode (m_CurMode);
+					BuildTagsList ();
+					break;
+				case GDK_z:
+					m_pView->GetDoc ()->OnUndo ();
+					return true;
+				case GDK_Z:
+					m_pView->GetDoc ()->OnRedo ();
+					return true;
+				case GDK_c:
+					CopySelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
+					return true;
+				case GDK_v:
+					PasteSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
+					return true;
+				case GDK_x:
+					CutSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
+					return true;
+				default:
 					break;
-					case GDK_z:
-						m_pView->GetDoc ()->OnUndo ();
-						return true;
-					case GDK_Z:
-						m_pView->GetDoc ()->OnRedo ();
-						return true;
-					case GDK_c:
-						CopySelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
-						return true;
-					case GDK_v:
-						PasteSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
-						return true;
-					case GDK_x:
-						CutSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
-						return true;
-					default:
-						return false;
-				}
 			}
-			if (event->key.keyval == GDK_KP_Enter || event->key.keyval == GDK_Return ||
-								event->key.keyval == GDK_space)
-				return true;
-			if (!g_utf8_validate (((GdkEventKey*) event)->string, -1, NULL)) {
-				gsize r, w;
-				gchar* newstr = g_locale_to_utf8 (((GdkEventKey*) event)->string, ((GdkEventKey*) event)->length, &r, &w, NULL);
-				g_free (((GdkEventKey*) event)->string);
-				((GdkEventKey*) event)->string = newstr;
-				((GdkEventKey*) event)->length = w;
-			}
-/*			gnome_canvas_item_grab_focus ((GnomeCanvasItem*) m_Active);
-			GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (G_OBJECT_GET_CLASS (m_Active));
-			klass->event ((GnomeCanvasItem*) m_Active, event);*/
-			return true;
 		}
+		if (event->keyval == GDK_KP_Enter || event->keyval == GDK_Return ||
+							event->keyval == GDK_space) // not allowed in fragments
+			return true;
+		if (gtk_im_context_filter_keypress (m_ImContext, event))
+			return true;
+		m_Active->OnKeyPressed (event);
+		return true;
 	}
 	return false;
 }
@@ -233,7 +264,7 @@ bool gcpFragmentTool::CopySelection (GtkClipboard *clipboard)
 	if (!m_Active)
 		return false;
 	unsigned start, end;
-	gcp::Fragment *fragment = (gcp::Fragment*) g_object_get_data (G_OBJECT (m_Active), "object");
+	gcp::Fragment *fragment = dynamic_cast <gcp::Fragment *> (m_Active->GetClient ());
 	fragment->GetSelectionBounds (start, end);
 	if (start == end)
 		return false;
@@ -279,7 +310,7 @@ bool gcpFragmentTool::Unselect ()
 {
 	if (!m_Active)
 		return true;
-	gcp::Fragment *fragment = (gcp::Fragment*) g_object_get_data (G_OBJECT (m_Active), "object");
+	gcp::Fragment *fragment = dynamic_cast <gcp::Fragment*> (m_Active->GetClient ());;
 	if (fragment->Validate ())
 		return gcpTextTool::Unselect ();
 	return false;
@@ -306,3 +337,79 @@ void gcpFragmentTool::OnGetData (GtkClipboard *clipboard, GtkSelectionData *sele
 	if (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD))
 		m_pApp->ActivateWindowsActionWidget ("/MainMenu/EditMenu/Paste", true);
 }
+
+void gcpFragmentTool::BuildTagsList ()
+{
+	if (!m_Active)
+		return;
+	gccv::TextTagList *l = new gccv::TextTagList ();
+	switch (m_CurMode) {
+	case gcp::Fragment::AutoMode:
+	case gcp::Fragment::NormalMode:
+		break;
+	case gcp::Fragment::SubscriptMode:
+		l->push_back (new gccv::PositionTextTag (gccv::Subscript, GetSize (), false));
+		break;
+	case gcp::Fragment::SuperscriptMode:
+		l->push_back (new gccv::PositionTextTag (gccv::Superscript, GetSize (), false));
+		break;
+	case gcp::Fragment::ChargeMode:
+		l->push_back (new gcp::ChargeTextTag (GetSize ()));
+		break;
+	case gcp::Fragment::StoichiometryMode:
+		l->push_back (new gcp::StoichiometryTextTag (GetSize ()));
+		break;
+	}
+	m_Active->SetCurTagList (l);
+	if (m_pView)
+		gtk_window_present (m_pView->GetDoc ()->GetWindow ()->GetWindow ());
+}
+
+void gcpFragmentTool::OnCommit (G_GNUC_UNUSED GtkIMContext *context, const gchar *str, gcpFragmentTool *tool)
+{
+	std::string s = (!strcmp (str, "-") && (tool->m_CurMode == gcp::Fragment::AutoMode || tool->m_CurMode == gcp::Fragment::ChargeMode))? "−": str;
+	unsigned start, end;
+	tool->m_Active->GetSelectionBounds (start, end);
+	if (start > end) {
+		unsigned n = end;
+		end = start;
+		start = n;
+	}
+	tool->m_Active->ReplaceText (s, start, end - start);
+}
+
+void gcpFragmentTool::UpdateTagsList () {
+	// FIXME: write this
+	gccv::TextTagList *l = new gccv::TextTagList ();
+	if (m_Active) {
+		list <gccv::TextTag *> const *cur = m_Active->GetTags ();
+		unsigned start, end;
+		m_Active->GetSelectionBounds (start, end);
+		list <gccv::TextTag *>::const_iterator i, iend = cur->end ();
+		for (i = cur->begin (); i != iend; i++)
+			if ((*i)->GetStartIndex () < end && (*i)->GetEndIndex () >= end) {
+				l->push_front ((*i)->Duplicate ());
+				gccv::Tag tag = (*i)->GetTag ();
+				if (tag == gccv::Position) {
+					bool stacked;
+					double size;
+					switch (static_cast <gccv::PositionTextTag *> (*i)->GetPosition (stacked, size)) {
+					case gccv::Normalscript:
+						break;
+					case gccv::Subscript:
+						m_CurMode = gcp::Fragment::SubscriptMode;
+						break;
+					case gccv::Superscript:
+						m_CurMode = gcp::Fragment::SuperscriptMode;
+						break;
+					}
+				} else if (tag == gcp::ChargeTag)
+					m_CurMode = gcp::Fragment::ChargeMode;
+				else if (tag == gcp::StoichiometryTag)
+					m_CurMode = gcp::Fragment::StoichiometryMode;
+			}
+		m_Fragment->SetMode (m_CurMode);
+		m_Active->SetCurTagList (l); // no tag
+	}
+}
+
