@@ -4,7 +4,7 @@
  * GChemPaint text plugin
  * texttool.cc 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,7 +35,7 @@
 #include <gcp/window.h>
 #include <gccv/text.h>
 #include <gccv/text-tag.h>
-#include <goffice/gtk/go-color-selector.h>
+#include <gcu/ui-builder.h>
 #include <gdk/gdkkeysyms.h>
 #include <unistd.h>
 #include <cstring>
@@ -54,58 +54,6 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 	tool->OnGetData (clipboard, selection_data, info);
 }
 
-static void on_sel_changed (gcpTextTool *tool)
-{
-	tool->UpdateTagsList ();
-}
-
-static bool filter_attribute (PangoAttribute *attribute, gcpTextTool *tool)
-{
-	int index = tool->GetIndex ();
-	if (index < 0)
-		return false;
-	if ((index)? (attribute->start_index < (unsigned) index && attribute->end_index >= (unsigned) index):
-		attribute->start_index == 0) {
-			switch (attribute->klass->type) {
-				case PANGO_ATTR_FAMILY:
-					tool->SetFamilyName (((PangoAttrString*)attribute)->value);
-					break;
-				case PANGO_ATTR_STYLE:
-					tool->SetStyle ((PangoStyle) ((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_WEIGHT:
-					tool->SetWeight ((PangoWeight) ((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_VARIANT:
-					tool->SetVariant ((PangoVariant) ((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_STRETCH:
-					tool->SetStretch ((PangoStretch) ((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_SIZE:
-					tool->SetSize (((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_UNDERLINE:
-					tool->SetUnderline ((PangoUnderline) ((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_STRIKETHROUGH:
-					tool->SetStrikethrough (((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_RISE:
-					tool->SetRise (((PangoAttrInt*)attribute)->value);
-					break;
-				case PANGO_ATTR_FOREGROUND: {
-					PangoColor color = ((PangoAttrColor*)attribute)->color;
-					tool->SetColor (RGBA_TO_UINT(color.red >> 8, color.green >> 8, color.blue >> 8, 0xff));
-					break;
-				}
-				default:
-					break;
-			}
-		}
-	return false;
-}
-
 gcpTextTool::gcpTextTool (gcp::Application* App, string Id):
 	gcp::Tool (App, Id),
 	m_FamilyList (NULL)
@@ -125,7 +73,6 @@ gcpTextTool::gcpTextTool (gcp::Application* App, string Id):
 	m_Underline = PANGO_UNDERLINE_NONE;
 	m_Rise = 0;
 	m_Color = RGBA_BLACK;
-	m_SelSignal = 0;
 	m_Position = gccv::Normalscript;
 }
 
@@ -159,15 +106,16 @@ bool gcpTextTool::OnClicked ()
 	if (m_pObject) {
 		if (m_pObject->GetType () != TextType)
 			return false;
-		static_cast <gcp::Text *> (m_pObject)->SetSelected (gcp::SelStateUpdating);
+		gcp::Text *text = static_cast <gcp::Text *> (m_pObject);
+		text->SetSelected (gcp::SelStateUpdating);
 		m_Active = static_cast <gccv::Text *> (dynamic_cast <gccv::ItemClient *> (m_pObject)->GetItem ());
 		m_pView->SetTextActive (m_Active);
 		m_Active->SetEditing (true);
+		m_Active->OnButtonPressed (m_x0, m_y0);
 		m_CurNode = ((gcp::Text*) m_pObject)->SaveSelected ();
 		m_InitNode = ((gcp::Text*) m_pObject)->SaveSelected ();
 		m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", false);
-/*		if (m_SelSignal == 0)
-			m_SelSignal = g_signal_connect_swapped (m_Active, "sel-changed", G_CALLBACK (on_sel_changed), this);*/
+		text->SetEditor (this);
 		if (create)
 			BuildTagsList ();
 		else
@@ -176,130 +124,85 @@ bool gcpTextTool::OnClicked ()
 	return true;
 }
 
-bool gcpTextTool::OnEvent (GdkEvent* event)
+void gcpTextTool::OnDrag ()
+{
+	if (m_Active)
+		m_Active->OnDrag (m_x, m_y);
+}
+
+bool gcpTextTool::OnKeyPress (GdkEventKey* event)
 {
 	if (m_Active) {
-		if ((event->type == GDK_KEY_PRESS) || (event->type == GDK_KEY_RELEASE)) {
-			if (event->key.state & GDK_CONTROL_MASK) {
-				switch (event->key.keyval) {
-				case GDK_Right:
-				case GDK_Left:
-				case GDK_Up:
-				case GDK_Down:
-				case GDK_End:
-				case GDK_Home:
-				case GDK_Delete:
-				case GDK_KP_Delete:
-				case GDK_BackSpace:
-					break;
-				case GDK_a:
-					m_pView->OnSelectAll ();
-					return true;
-				case GDK_z:
-					m_pView->GetDoc()->OnUndo ();
-					return true;
-				case GDK_Z:
-					m_pView->GetDoc()->OnRedo ();
-					return true;
-				case GDK_c:
-					CopySelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
-					return true;
-				case GDK_v:
-					PasteSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
-					return true;
-				case GDK_x:
-					CutSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
-					return true;
-				case GDK_i:
-					m_Style = (m_Style == PANGO_STYLE_NORMAL)? PANGO_STYLE_ITALIC: PANGO_STYLE_NORMAL;
-					SelectBestFontFace ();
-					BuildTagsList ();
-					return true;
-				case GDK_u:
-					gtk_combo_box_set_active (m_UnderlineBox, ((m_Underline == PANGO_UNDERLINE_SINGLE)? PANGO_UNDERLINE_NONE: PANGO_UNDERLINE_SINGLE));
-					return true;
-				case GDK_b:
-					m_Weight = (m_Weight == PANGO_WEIGHT_NORMAL)? PANGO_WEIGHT_BOLD: PANGO_WEIGHT_NORMAL;
-					SelectBestFontFace ();
-					BuildTagsList ();
-					return true;
-				case GDK_k:
-					gtk_toggle_button_set_active (m_StrikethroughBtn, !m_Strikethrough);
-					return true;
-				case GDK_plus:
-				case GDK_dead_circumflex:
-					m_Position = (m_Position == gccv::Superscript)? gccv::Normalscript: gccv::Superscript;
-					BuildTagsList ();
-/*					if (m_Rise == 0) {
-						m_Size = m_Size * 2 / 3;
-						m_Rise = m_Size / PANGO_SCALE;
-					} else if (m_Rise < 0)
-						m_Rise = m_Size / PANGO_SCALE;
-					else {
-						m_Size = m_Size * 3 / 2;
-						m_Rise = 0;
-					}
-					g_signal_handler_block (m_RiseButton, m_RiseSignal);
-					gtk_spin_button_set_value (m_RiseButton, m_Rise);
-					m_Rise *= PANGO_SCALE;
-					g_signal_handler_unblock (m_RiseButton, m_RiseSignal);
-					SetSizeFull (true);*/
-					return true;
-				case GDK_equal:
-				case GDK_underscore:
-					m_Position = (m_Position == gccv::Subscript)? gccv::Normalscript: gccv::Subscript;
-					BuildTagsList ();
-/*					if (m_Rise == 0) {
-						m_Size = m_Size * 2 / 3;
-						m_Rise = - m_Size / PANGO_SCALE / 2;
-					} else if (m_Rise > 0)
-						m_Rise = - m_Size / PANGO_SCALE/ 2;
-					else {
-						m_Size = m_Size * 3 / 2;
-						m_Rise = 0;
-					}
-					g_signal_handler_block (m_RiseButton, m_RiseSignal);
-					gtk_spin_button_set_value (m_RiseButton, m_Rise);
-					m_Rise *= PANGO_SCALE;
-					g_signal_handler_unblock (m_RiseButton, m_RiseSignal);
-					SetSizeFull (true);*/
-					return true;
-				case GDK_space: {
-					gccv::Text *saved = m_Active;
-					m_Active = NULL;
-					UpdateTagsList ();
-					m_Active = saved;
-					BuildTagsList ();
-					return true;
-				}
-				default:
-					break;
-				}
-			}
-			if (event->type == GDK_KEY_PRESS) {
-				if (!g_utf8_validate (((GdkEventKey*) event)->string, -1, NULL)) {
-					gsize r, w;
-					gchar* newstr = g_locale_to_utf8 (((GdkEventKey*) event)->string, ((GdkEventKey*) event)->length, &r, &w, NULL);
-					g_free (((GdkEventKey*) event)->string);
-					((GdkEventKey*) event)->string = newstr;
-					((GdkEventKey*) event)->length = w;
-				}
-				m_Active->OnKeyPressed (reinterpret_cast <GdkEventKey *> (event));
-/*			gnome_canvas_item_grab_focus ((GnomeCanvasItem*) m_Active);
-			GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (G_OBJECT_GET_CLASS (m_Active));
-			klass->event ((GnomeCanvasItem*) m_Active, event);*/
+		if (event->state & GDK_CONTROL_MASK) {
+			switch (event->keyval) {
+			case GDK_Right:
+			case GDK_Left:
+			case GDK_Up:
+			case GDK_Down:
+			case GDK_End:
+			case GDK_Home:
+			case GDK_Delete:
+			case GDK_KP_Delete:
+			case GDK_BackSpace:
+				break;
+			case GDK_a:
+				m_pView->OnSelectAll ();
 				return true;
-			} else
-				return false;
-		} else if (event->type == GDK_BUTTON_PRESS) {
-			 switch (event->button.button) {
-				case 2:
+			case GDK_z:
+				m_pView->GetDoc()->OnUndo ();
+				return true;
+			case GDK_Z:
+				m_pView->GetDoc()->OnRedo ();
+				return true;
+			case GDK_c:
+				CopySelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
+				return true;
+			case GDK_v:
+				PasteSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
+				return true;
+			case GDK_x:
+				CutSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
+				return true;
+			case GDK_i:
+				m_Style = (m_Style == PANGO_STYLE_NORMAL)? PANGO_STYLE_ITALIC: PANGO_STYLE_NORMAL;
+				SelectBestFontFace ();
+				BuildTagsList ();
+				return true;
+			case GDK_u:
+				gtk_combo_box_set_active (m_UnderlineBox, ((m_Underline == PANGO_UNDERLINE_SINGLE)? PANGO_UNDERLINE_NONE: PANGO_UNDERLINE_SINGLE));
+				return true;
+			case GDK_b:
+				m_Weight = (m_Weight == PANGO_WEIGHT_NORMAL)? PANGO_WEIGHT_BOLD: PANGO_WEIGHT_NORMAL;
+				SelectBestFontFace ();
+				BuildTagsList ();
+				return true;
+			case GDK_k:
+				gtk_toggle_button_set_active (m_StrikethroughBtn, !m_Strikethrough);
+				return true;
+			case GDK_plus:
+			case GDK_dead_circumflex:
+				m_Position = (m_Position == gccv::Superscript)? gccv::Normalscript: gccv::Superscript;
+				BuildTagsList ();
+				return true;
+			case GDK_equal:
+			case GDK_underscore:
+				m_Position = (m_Position == gccv::Subscript)? gccv::Normalscript: gccv::Subscript;
+				BuildTagsList ();
+				return true;
+			case GDK_space: {
+				gccv::Text *saved = m_Active;
+				m_Active = NULL;
+				UpdateTagsList ();
+				m_Active = saved;
+				BuildTagsList ();
 				return true;
 			}
-		} else if (event->type == GDK_MOTION_NOTIFY) {
-/*			GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (G_OBJECT_GET_CLASS (m_Active));
-			klass->event ((GnomeCanvasItem*) m_Active, event);*/
+			default:
+				break;
+			}
 		}
+		m_Active->OnKeyPressed (event);
+		return true;
 	}
 	return false;
 }
@@ -326,10 +229,6 @@ bool gcpTextTool::Unselect ()
 {
 	if (!m_Active)
 		return true;
-	if (m_SelSignal) {
-		g_signal_handler_disconnect (m_Active, m_SelSignal);
-		m_SelSignal = 0;
-	}
 	m_pView->SetTextActive (NULL);
 	m_Active->SetEditing (false);
 	m_Active->GetClient ()->SetSelected (gcp::SelStateUnselected);
@@ -391,6 +290,7 @@ bool gcpTextTool::Unselect ()
 		m_pView->GetDoc ()->Remove (pObj);
 		m_pView->GetDoc ()->AbortOperation ();
 	}
+	m_pView->GetDoc ()->FinishOperation ();
 	m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", m_pView->GetDoc ()->HasChildren ());
 	return true;
 }
@@ -400,14 +300,13 @@ bool gcpTextTool::DeleteSelection ()
 	if (!m_Active)
 		return false;
 	unsigned start, end;
+	std::string s = "";
 
-	gcp::TextObject *text = dynamic_cast<gcp::TextObject*> ((Object*) g_object_get_data (G_OBJECT (m_Active), "object"));
+	gcp::TextObject *text = dynamic_cast <gcp::TextObject*> (m_Active->GetClient ());
 	if (!text)
 		return false;
 	text->GetSelectionBounds (start, end);
-/*	gcp_pango_layout_replace_text (gnome_canvas_pango_get_layout (m_Active),
-												start, end - start, "", NULL);
-	gnome_canvas_pango_set_selection_bounds (m_Active, start, start);*/
+	m_Active->ReplaceText (s, start, end - start);
 	text->OnChanged (true);
 	return true;
 }
@@ -417,7 +316,7 @@ bool gcpTextTool::CopySelection (GtkClipboard *clipboard)
 	if (!m_Active)
 		return false;
 	unsigned start, end;
-	gcp::Text *text = (gcp::Text*) g_object_get_data (G_OBJECT (m_Active), "object");
+	gcp::Text *text = dynamic_cast <gcp::Text*> (m_Active->GetClient ());
 	text->GetSelectionBounds (start, end);
 	if (start == end)
 		return false;
@@ -474,19 +373,20 @@ static bool filter_fragment (PangoAttribute *attr, struct FragState *s)
 	return false;
 }
 
-bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, G_GNUC_UNUSED int type)
+bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *selection_data, G_GNUC_UNUSED int type)
 {
 	if (!m_Active)
 		return false;
 	guint *DataType = (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD))? &gcp::ClipboardDataType: &gcp::ClipboardDataType1;
-	g_return_val_if_fail ((data->target == gdk_atom_intern (gcp::targets[*DataType].target, FALSE)), FALSE);
-	gcp::Text *text = (gcp::Text*) g_object_get_data (G_OBJECT (m_Active), "object");
+	g_return_val_if_fail ((gtk_selection_data_get_target (selection_data) == gdk_atom_intern (gcp::targets[*DataType].target, FALSE)), FALSE);
+	int length = gtk_selection_data_get_length (selection_data);
+	char const *data = reinterpret_cast <char const *> (gtk_selection_data_get_data (selection_data));
+	gcp::Text *text = dynamic_cast <gcp::Text*> (m_Active->GetClient ());
 	unsigned start, end;
 	text->GetSelectionBounds (start, end);
-	PangoLayout *layout = NULL; // FIXME
 	switch (*DataType) {
 		case gcp::GCP_CLIPBOARD_NATIVE: {
-			xmlDocPtr xml = xmlParseMemory ((const char*) data->data, data->length);
+			xmlDocPtr xml = xmlParseMemory (data, length);
 			xmlNodePtr node = xml->children;
 			if ((strcmp((char*)node->name, "chemistry")) || (node->children->next)) {
 				xmlFreeDoc (xml);
@@ -494,12 +394,12 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, G_
 			}
 			node = node->children;
 			if (!strcmp ((char*) node->name, "text")) {
-//				gcp_pango_layout_replace_text (layout, start, end - start, "", NULL);
 				text->LoadSelection (node, start);
 				xmlFreeDoc (xml);
-				return true; // otherwise, we'd call OnChange(true) twice.
+				return true; // otherwise, we'd call OnChanged (true) twice.
 			} else if (!strcmp((char*)node->name, "fragment")) {
-				gcp::Fragment* fragment = new gcp::Fragment ();
+// FIXME
+/*				gcp::Fragment* fragment = new gcp::Fragment ();
 				gcp::Document *pDoc = m_pView->GetDoc ();
 				gcp::Theme *pTheme = pDoc->GetTheme ();
 				pDoc->AddChild (fragment);
@@ -509,18 +409,7 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, G_
 				PangoAttribute *attr = pango_attr_family_new (pTheme->GetFontFamily ());
 				pango_attr_list_insert (l, attr);
 				attr = pango_attr_size_new (pTheme->GetFontSize ());
-				pango_attr_list_insert (l, attr);
-// FIXME
-/*				gcp_pango_layout_replace_text (layout, start, end - start, buf.c_str (), l);
-				pango_attr_list_unref (l);
-				l = fragment->GetAttrList ();
-				struct FragState s;
-				s.l = pango_layout_get_attributes (layout);
-				s.start = start;
-				pango_attr_list_filter (l, (PangoAttrFilterFunc) filter_fragment, &s);
-				delete fragment;
-				start += buf.length ();
-				gnome_canvas_pango_set_selection_bounds (m_Active, start, start);*/
+				pango_attr_list_insert (l, attr);*/
 			} else {
 				xmlFreeDoc (xml);
 				return false;
@@ -529,21 +418,21 @@ bool gcpTextTool::OnReceive (GtkClipboard *clipboard, GtkSelectionData *data, G_
 			break;
 		}
 		case gcp::GCP_CLIPBOARD_UTF8_STRING: {
-/*			PangoAttrList *l = pango_attr_list_new ();
-//			gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
-			pango_attr_list_unref (l);*/
+			string s (data);
+			m_Active->ReplaceText (s, static_cast <int> (start), start - end);
 			break;
 		}
 		case gcp::GCP_CLIPBOARD_STRING: {
-//			PangoAttrList *l = pango_attr_list_new ();
-			if (!g_utf8_validate ((const char*) data->data, data->length, NULL)) {
+			if (!g_utf8_validate (data, length, NULL)) {
 				gsize r, w;
-				gchar* newstr = g_locale_to_utf8 ((const char*) data->data, data->length, &r, &w, NULL);
-//				gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
+				char* newstr = g_locale_to_utf8 (data, length, &r, &w, NULL);
+				string s (newstr);
+				m_Active->ReplaceText (s, static_cast <int> (start), start - end);
 				g_free (newstr);
-			} else
-//				gcp_pango_layout_replace_text (layout, start, end - start, (char const *) data->data, l);
-//			pango_attr_list_unref (l);
+			} else {
+				string s (data);
+				m_Active->ReplaceText (s, static_cast <int> (start), start - end);
+			}
 			break;
 		}
 	}
@@ -568,7 +457,7 @@ bool gcpTextTool::OnUndo ()
 		return false;
 	}
 	xmlNodePtr node = m_UndoList.front();
-	gcp::TextObject *text = (gcp::TextObject*) g_object_get_data (G_OBJECT (m_Active), "object");
+	gcp::TextObject *text = dynamic_cast <gcp::TextObject*> (m_Active->GetClient ());
 	text->LoadSelected (node);
 	m_UndoList.pop_front ();
 	gcp::Document *pDoc = m_pView->GetDoc ();
@@ -577,14 +466,6 @@ bool gcpTextTool::OnUndo ()
 		pWin->ActivateActionWidget ("/MainMenu/EditMenu/Undo", false);
 	m_RedoList.push_front(m_CurNode);
 	pWin->ActivateActionWidget ("/MainMenu/EditMenu/Redo", true);
-	unsigned start, end;
-	char* tmp = (char*) xmlGetProp (node, (xmlChar*) "start-sel");
-	start = (int) strtoul (tmp, NULL, 10);
-	xmlFree (tmp);
-	tmp = (char*) xmlGetProp (node, (xmlChar*) "end-sel");
-	end = (int) strtoul (tmp, NULL, 10);
-	xmlFree (tmp);
-//	gnome_canvas_pango_set_selection_bounds (m_Active, start, end);
 	m_CurNode = node;
 	return true;
 }
@@ -594,7 +475,7 @@ bool gcpTextTool::OnRedo ()
 	if (m_RedoList.empty ())
 		return false;
 	xmlNodePtr node = m_RedoList.front ();
-	gcp::TextObject *text = (gcp::TextObject*) g_object_get_data (G_OBJECT (m_Active), "object");
+	gcp::TextObject *text = dynamic_cast <gcp::TextObject*> (m_Active->GetClient ());
 	text->LoadSelected (node);
 	m_RedoList.pop_front ();
 	gcp::Window *pWin = m_pView->GetDoc ()->GetWindow ();
@@ -602,14 +483,6 @@ bool gcpTextTool::OnRedo ()
 		pWin->ActivateActionWidget ("/MainMenu/EditMenu/Redo", false);
 	m_UndoList.push_front (m_CurNode);
 	pWin->ActivateActionWidget ("/MainMenu/EditMenu/Undo", true);
-	unsigned start, end;
-	char* tmp = (char*) xmlGetProp (node, (xmlChar*) "start-sel");
-	start = (int) strtoul (tmp, NULL, 10);
-	xmlFree (tmp);
-	tmp = (char*) xmlGetProp (node, (xmlChar*) "end-sel");
-	end = (int) strtoul (tmp, NULL, 10);
-	xmlFree (tmp);
-//	gnome_canvas_pango_set_selection_bounds (m_Active, start, end);
 	m_CurNode = node;
 	return true;
 }
@@ -668,11 +541,54 @@ void gcpTextTool::UpdateTagsList ()
 	m_Strikethrough = false;
 	m_Color = RGBA_BLACK;
 	if (m_Active) {
-/*		PangoLayout *layout;
-		g_object_get (m_Active, "layout", &layout, NULL);
-		PangoAttrList *l = pango_layout_get_attributes (layout);
-		if (l)
-			pango_attr_list_filter (l, (PangoAttrFilterFunc) filter_attribute, this);*/
+		unsigned index = GetIndex ();
+		std::list <gccv::TextTag *> const *tags = m_Active->GetTags ();
+		std::list <gccv::TextTag *>::const_iterator i, end = tags->end ();
+		for (i = tags->begin (); i != end; i++) {
+			if ((index)? ((*i)->GetStartIndex () < index && (*i)->GetEndIndex () >=  index):
+				(*i)->GetStartIndex () == 0) {
+				switch ((*i)->GetTag ()) {
+				case gccv::Family:
+					m_FamilyName = static_cast <gccv::FamilyTextTag const *> (*i)->GetFamily ();
+					break;
+				case gccv::Size:
+					m_Size = static_cast <gccv::SizeTextTag const *> (*i)->GetSize ();
+					break;
+				case gccv::Style:
+					m_Style = static_cast <gccv::StyleTextTag const *> (*i)->GetStyle ();
+					break;
+				case gccv::Weight:
+					m_Weight = static_cast <gccv::WeightTextTag const *> (*i)->GetWeight ();
+					break;
+				case gccv::Variant:
+					m_Variant = static_cast <gccv::VariantTextTag const *> (*i)->GetVariant ();
+					break;
+				case gccv::Stretch:
+					m_Stretch = static_cast <gccv::StretchTextTag const *> (*i)->GetStretch ();
+					break;
+				case gccv::Underline:
+					m_Underline = static_cast <gccv::UnderlineTextTag const *> (*i)->GetUnderline ();
+					break;
+				case gccv::Strikethrough:
+					m_Strikethrough = static_cast <gccv::StrikethroughTextTag const *> (*i)->GetStrikethrough ();
+					break;
+				case gccv::Foreground:
+					m_Color = static_cast <gccv::ForegroundTextTag const *> (*i)->GetColor ();
+					break;
+				case gccv::Rise:
+					m_Rise = static_cast <gccv::RiseTextTag const *> (*i)->GetRise ();
+					break;
+				case gccv::Position: {
+					bool stacked;
+					double size;
+					m_Position = static_cast <gccv::PositionTextTag const *> (*i)->GetPosition (stacked, size);
+					break;
+				}
+				default:
+					break;
+				}
+			}
+		}
 	}
 	// select the found face
 	GtkTreeIter iter;
@@ -680,16 +596,20 @@ void gcpTextTool::UpdateTagsList ()
 	gtk_tree_model_get_iter_first (GTK_TREE_MODEL (m_FamilyList), &iter);
 	do {
 		gtk_tree_model_get (GTK_TREE_MODEL (m_FamilyList), &iter, 0, &buf, -1);
-		if (!strcmp (m_FamilyName, buf)) {
+		if (m_FamilyName == buf) {
 			m_Dirty = true;
 			GtkTreePath *path = gtk_tree_model_get_path (GTK_TREE_MODEL (m_FamilyList), &iter);
+			g_signal_handler_block (m_FamilySel, m_FamilySignal);
+			g_signal_handler_block (m_FaceSel, m_FaceSignal);
 			gtk_tree_view_set_cursor (m_FamilyTree, path, NULL, FALSE);
+			g_signal_handler_unblock (m_FaceSel, m_FaceSignal);
+			g_signal_handler_unblock (m_FamilySel, m_FamilySignal);
 			gtk_tree_path_free (path);
 			break;
 		}
 	} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (m_FamilyList), &iter));
 	// Update other widgets
-	SetSizeFull (true);
+	SetSizeFull (true, false);
 	g_signal_handler_block (m_UnderlineBox, m_UnderlineSignal);
 	gtk_combo_box_set_active (m_UnderlineBox, m_Underline);
 	g_signal_handler_unblock (m_UnderlineBox, m_UnderlineSignal);
@@ -787,14 +707,14 @@ static const guint16 font_sizes[] = {
 
 GtkWidget *gcpTextTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (GLADEDIR"/fontsel.glade", "fontsel", GETTEXT_PACKAGE);
+	gcu::UIBuilder *builder = new gcu::UIBuilder (UIDIR"/fontsel.ui", GETTEXT_PACKAGE);
 	PangoFontFamily **families;
 	int i, nb;
 	gcp::Theme *pTheme = m_pApp->GetActiveDocument ()->GetTheme ();
 	// Initialize faces list
 	m_FaceList = gtk_list_store_new (1, G_TYPE_STRING);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (m_FaceList), 0, GTK_SORT_ASCENDING);
-	m_FacesTree = (GtkTreeView *) glade_xml_get_widget (xml, "style");
+	m_FacesTree = GTK_TREE_VIEW (builder->GetWidget ("style"));
 	gtk_tree_view_set_model (m_FacesTree, GTK_TREE_MODEL (m_FaceList));
 	GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
 	GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes (NULL, renderer, "text", 0, NULL);
@@ -804,7 +724,7 @@ GtkWidget *gcpTextTool::GetPropertyPage ()
 	m_FaceSignal = g_signal_connect (m_FaceSel, "changed", G_CALLBACK (on_select_face), this);
 	// Initialize sizes list
 	m_SizeList = gtk_list_store_new (1, G_TYPE_INT);
-	m_SizesTree = (GtkTreeView *) glade_xml_get_widget (xml, "size-list");
+	m_SizesTree = GTK_TREE_VIEW (builder->GetWidget ("size-list"));
 	gtk_tree_view_set_model (m_SizesTree, GTK_TREE_MODEL (m_SizeList));
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (NULL, renderer, "text", 0, NULL);
@@ -820,15 +740,15 @@ GtkWidget *gcpTextTool::GetPropertyPage ()
 	m_SizeSel = selection;
 	m_SizeSignal = g_signal_connect (m_SizeSel, "changed", G_CALLBACK (on_select_size), this);
 	// Size entry
-	m_SizeEntry = (GtkEntry*) glade_xml_get_widget (xml, "size-entry");
+	m_SizeEntry = GTK_ENTRY (builder->GetWidget ("size-entry"));
 	g_signal_connect (m_SizeEntry, "activate", G_CALLBACK (on_size_activate), this);
 	g_signal_connect_after (m_SizeEntry, "focus_out_event", G_CALLBACK (on_size_focus_out), this);
-	SetSizeFull (true);
+	SetSizeFull (true, false);
 	PangoContext *pc = gtk_widget_get_pango_context (GTK_WIDGET (m_SizeEntry));
 	pango_context_list_families (pc, &families, &nb);
 	m_FamilyList = gtk_list_store_new (1, G_TYPE_STRING);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (m_FamilyList), 0, GTK_SORT_ASCENDING);
-	m_FamilyTree = (GtkTreeView *) glade_xml_get_widget (xml, "family");
+	m_FamilyTree = GTK_TREE_VIEW (builder->GetWidget ("family"));
 	gtk_tree_view_set_model (m_FamilyTree, GTK_TREE_MODEL (m_FamilyList));
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (NULL, renderer, "text", 0, NULL);
@@ -872,19 +792,21 @@ GtkWidget *gcpTextTool::GetPropertyPage ()
 		gtk_tree_view_scroll_to_cell (m_FamilyTree, path, column, FALSE, 0., 0.);
 		gtk_tree_path_free (path);
 	}
-	m_UnderlineBox = GTK_COMBO_BOX (glade_xml_get_widget (xml, "underline"));
+	m_UnderlineBox = GTK_COMBO_BOX (builder->GetWidget ("underline"));
 	gtk_combo_box_set_active (m_UnderlineBox, 0);
 	m_UnderlineSignal = g_signal_connect (G_OBJECT (m_UnderlineBox), "changed", G_CALLBACK (on_underline_changed), this);
-	m_StrikethroughBtn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "strikethrough"));
+	m_StrikethroughBtn = GTK_TOGGLE_BUTTON (builder->GetWidget ("strikethrough"));
 	m_StrikethroughSignal = g_signal_connect (G_OBJECT (m_StrikethroughBtn), "toggled", G_CALLBACK (on_strikethrough_toggled), this);
-	m_RiseButton = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "rise"));
+	m_RiseButton = GTK_SPIN_BUTTON (builder->GetWidget ("rise"));
 	m_RiseSignal = g_signal_connect (G_OBJECT (m_RiseButton), "value-changed", G_CALLBACK (on_rise_changed), this);
 	m_ColorSelector = GO_SELECTOR (go_color_selector_new (RGBA_BLACK, RGBA_BLACK, "fore"));
 	go_color_selector_set_allow_alpha (m_ColorSelector, false);
 	m_ForeSignal = g_signal_connect (G_OBJECT (m_ColorSelector), "activate", G_CALLBACK (on_fore_color_changed), this);
 	gtk_widget_show (GTK_WIDGET (m_ColorSelector));
-	gtk_table_attach (GTK_TABLE (glade_xml_get_widget (xml, "table2")), GTK_WIDGET (m_ColorSelector), 1, 2, 0, 1, (GtkAttachOptions) 0, (GtkAttachOptions) 0, 0, 0);
-	return glade_xml_get_widget (xml, "fontsel");
+	gtk_table_attach (GTK_TABLE (builder->GetWidget ("table2")), GTK_WIDGET (m_ColorSelector), 1, 2, 0, 1, (GtkAttachOptions) 0, (GtkAttachOptions) 0, 0, 0);
+	GtkWidget *res = builder->GetRefdWidget ("fontsel");
+	delete builder;
+	return res;
 }
 
 void gcpTextTool::OnSelectFamily (GtkTreeSelection *selection)
@@ -894,7 +816,8 @@ void gcpTextTool::OnSelectFamily (GtkTreeSelection *selection)
 	char const *name;
 	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
 		return;
-	gtk_tree_model_get (model, &iter, 0, &m_FamilyName, -1);
+	gtk_tree_model_get (model, &iter, 0, &name, -1);
+	m_FamilyName = name;
 	PangoFontFamily *family = m_Families[m_FamilyName];
 	PangoFontFace **faces;
 	int i, besti, nb;
@@ -947,14 +870,13 @@ void gcpTextTool::OnSelectFamily (GtkTreeSelection *selection)
 		//TODO: choose a face when default is not available
 	}
 	if (m_Active) {
-		PangoAttrList *l = pango_attr_list_new ();
-		pango_attr_list_insert (l, pango_attr_family_new (m_FamilyName));
-		pango_attr_list_insert (l, pango_attr_style_new (m_Style));
-		pango_attr_list_insert (l, pango_attr_weight_new (m_Weight));
-		pango_attr_list_insert (l, pango_attr_stretch_new (m_Stretch));
-		pango_attr_list_insert (l, pango_attr_variant_new (m_Variant));
-//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
-		pango_attr_list_unref (l);
+		gccv::TextTagList l;
+		l.push_front (new gccv::FamilyTextTag (m_FamilyName));
+		l.push_front (new gccv::StyleTextTag (m_Style));
+		l.push_front (new gccv::WeightTextTag (m_Weight));
+		l.push_front (new gccv::StretchTextTag (m_Stretch));
+		l.push_front (new gccv::VariantTextTag (m_Variant));
+		m_Active->ApplyTagsToSelection (&l);
 	}
 }
 
@@ -975,30 +897,29 @@ void gcpTextTool::OnSelectFace (GtkTreeSelection *selection)
 	pango_font_description_free (desc);
 	BuildTagsList ();
 	if (m_Active) {
-		PangoAttrList *l = pango_attr_list_new ();
-		pango_attr_list_insert (l, pango_attr_style_new (m_Style));
-		pango_attr_list_insert (l, pango_attr_weight_new (m_Weight));
-		pango_attr_list_insert (l, pango_attr_stretch_new (m_Stretch));
-		pango_attr_list_insert (l, pango_attr_variant_new (m_Variant));
-//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
-		pango_attr_list_unref (l);
+		gccv::TextTagList l;
+		l.push_front (new gccv::StyleTextTag (m_Style));
+		l.push_front (new gccv::WeightTextTag (m_Weight));
+		l.push_front (new gccv::StretchTextTag (m_Stretch));
+		l.push_front (new gccv::VariantTextTag (m_Variant));
+		m_Active->ApplyTagsToSelection (&l);
 	}
 }
 
 void gcpTextTool::OnSelectSize (int size)
 {
 	m_Size = size;
-	SetSizeFull (false);
+	SetSizeFull (false, true);
 }
 
 void gcpTextTool::OnSizeChanged ()
 {
 	char const *text = gtk_entry_get_text (m_SizeEntry);
 	m_Size = (int) (MAX (0.1, atof (text) * PANGO_SCALE + 0.5));
-	SetSizeFull (true);
+	SetSizeFull (true, true);
 }
 
-void gcpTextTool::SetSizeFull (bool update_list)
+void gcpTextTool::SetSizeFull (bool update_list, bool apply)
 {
 	char *buf = g_strdup_printf ("%.1f", (double) m_Size / PANGO_SCALE);
 	gtk_entry_set_text (m_SizeEntry, buf);
@@ -1026,11 +947,10 @@ void gcpTextTool::SetSizeFull (bool update_list)
 		g_signal_handler_unblock (selection, m_SizeSignal);
 	}
 	BuildTagsList ();
-	if (m_Active) {
-		PangoAttrList *l = pango_attr_list_new ();
-		pango_attr_list_insert (l, pango_attr_size_new (m_Size));
-//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
-		pango_attr_list_unref (l);
+	if (apply && m_Active) {
+		gccv::TextTagList l;
+		l.push_front (new gccv::SizeTextTag (m_Size));
+		m_Active->ApplyTagsToSelection (&l);
 	}
 }
 
@@ -1089,10 +1009,9 @@ void gcpTextTool::OnUnderlineChanged (unsigned underline)
 	m_Underline = (PangoUnderline) underline;
 	BuildTagsList ();
 	if (m_Active) {
-		PangoAttrList *l = pango_attr_list_new ();
-		pango_attr_list_insert (l, pango_attr_underline_new (m_Underline));
-//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
-		pango_attr_list_unref (l);
+		gccv::TextTagList l;
+		l.push_front (new gccv::UnderlineTextTag (m_Underline));
+		m_Active->ApplyTagsToSelection (&l);
 	}
 }
 
@@ -1101,10 +1020,9 @@ void gcpTextTool::OnStriketroughToggled (bool strikethrough)
 	m_Strikethrough = strikethrough;
 	BuildTagsList ();
 	if (m_Active) {
-		PangoAttrList *l = pango_attr_list_new ();
-		pango_attr_list_insert (l, pango_attr_strikethrough_new (m_Strikethrough));
-//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
-		pango_attr_list_unref (l);
+		gccv::TextTagList l;
+		l.push_front (new gccv::StrikethroughTextTag (m_Strikethrough));
+		m_Active->ApplyTagsToSelection (&l);
 	}
 }
 
@@ -1112,6 +1030,11 @@ void gcpTextTool::OnPositionChanged (int position)
 {
 	m_Rise = position * PANGO_SCALE;
 	BuildTagsList ();
+	if (m_Active) {
+		gccv::TextTagList l;
+		l.push_front (new gccv::RiseTextTag (m_Rise));
+		m_Active->ApplyTagsToSelection (&l);
+	}
 }
 
 void gcpTextTool::OnForeColorChanged (GOColor color)
@@ -1119,9 +1042,13 @@ void gcpTextTool::OnForeColorChanged (GOColor color)
 	m_Color = color;
 	BuildTagsList ();
 	if (m_Active) {
-		PangoAttrList *l = pango_attr_list_new ();
-		pango_attr_list_insert (l, pango_attr_foreground_new (UINT_RGBA_R (m_Color) * 0x101, UINT_RGBA_G (m_Color) * 0x101, UINT_RGBA_B (m_Color) * 0x101));
-//		gnome_canvas_pango_apply_attrs_to_selection (m_Active, l);
-		pango_attr_list_unref (l);
+		gccv::TextTagList l;
+		l.push_front (new gccv::ForegroundTextTag (m_Color));
+		m_Active->ApplyTagsToSelection (&l);
 	}
 }
+
+void gcpTextTool::SelectionChanged ()
+{
+	UpdateTagsList ();
+}
