@@ -4,7 +4,7 @@
  * GChemPaint text plugin
  * texttool.h 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,6 +27,7 @@
 
 #include <gccv/structs.h>
 #include <gcp/tool.h>
+#include <gcp/text-editor.h>
 #include <gcu/macros.h>
 #include <goffice/gtk/go-color-selector.h>
 #include <list>
@@ -37,16 +38,17 @@ namespace gccv {
 }
 using namespace std;
 
-class gcpTextTool: public gcp::Tool
+class gcpTextTool: public gcp::Tool, public gcp::TextEditor
 {
 public:
 	gcpTextTool (gcp::Application *App, string Id = "Text");
 	virtual ~gcpTextTool ();
 
 	bool OnClicked ();
+	void OnDrag ();
 	bool Deactivate ();
 	void Activate ();
-	bool OnEvent (GdkEvent *event);
+	bool OnKeyPress (GdkEventKey *event);
 	bool NotifyViewChange ();
 	bool DeleteSelection ();
 	bool CopySelection (GtkClipboard *clipboard);
@@ -62,14 +64,15 @@ public:
 	void OnSelectFace (GtkTreeSelection *selection);
 	void OnSelectSize (int size);
 	void OnSizeChanged ();
-	void SetSizeFull (bool update_list);
-	void UpdateTagsList ();
+	void SetSizeFull (bool update_list, bool apply);
+	virtual void UpdateTagsList ();
 	unsigned GetIndex ();
 	void OnUnderlineChanged (unsigned underline);
 	void OnStriketroughToggled (bool strikethrough);
 	void OnPositionChanged (int position);
 	void OnForeColorChanged (GOColor color);
 	char const *GetHelpTag () {return "text";}
+	void SelectionChanged ();
 
 protected:
 	virtual bool Unselect ();
@@ -100,9 +103,9 @@ private:
 	GtkToggleButton *m_StrikethroughBtn;
 	GtkSpinButton *m_RiseButton;
 	bool m_Dirty;
-	gulong m_SelSignal, m_UnderlineSignal, m_StrikethroughSignal, m_ForeSignal, m_RiseSignal;
+	gulong m_UnderlineSignal, m_StrikethroughSignal, m_ForeSignal, m_RiseSignal;
 
-GCU_PROP (char const *, FamilyName)
+GCU_PROP (std::string, FamilyName)
 GCU_PROP (PangoStyle, Style)
 GCU_PROP (PangoWeight, Weight)
 GCU_PROP (PangoStretch, Stretch)
