@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -38,7 +38,6 @@
 #include "cleavagesdlg.h"
 #include "globals.h"
 #include <gcu/filechooser.h>
-#include <glade/glade.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
 #include <clocale>
@@ -751,7 +750,7 @@ bool gcDocument::VerifySaved()
 	m_bClosing = true;
 	if (!GetDirty ())
 		return true;
-	gchar* str = g_strdup_printf(_("\"%s\" has been modified.  Do you wish to save it?"), m_title);
+	gchar* str = g_strdup_printf(_("\"%s\" has been modified.  Do you wish to save it?"), m_Label);
 	GtkWidget* mbox;
 	int res;
 	do
@@ -948,7 +947,7 @@ void gcDocument::SetMail (char const *mail)
 void gcDocument::SetComment (char const *comment)
 {
 	g_free (m_Comment);
-	m_Comment = g_strdup (m_Comment);
+	m_Comment = g_strdup (comment);
 }
 
 void gcDocument::SetLabel (char const *label)
