@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/spectra/window.cc
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,102 +27,96 @@
 #include "document.h"
 #include "view.h"
 #include "window.h"
-#include <goffice/gtk/go-graph-widget.h>
-#include <goffice/graph/gog-object-xml.h>
-#include <goffice/utils/go-locale.h>
-#include <goffice/utils/go-image.h>
+#include <gcu/print-setup-dlg.h>
 #include <gsf/gsf-output-memory.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkcontainer.h>
-#include <gtk/gtkwindow.h>
 #include <glib/gi18n.h>
 
 using namespace std;
 
 //Callbacks
-static bool on_delete_event (GtkWidget* widget, GdkEvent *event, gsvWindow* Win)
+static bool on_delete_event (G_GNUC_UNUSED GtkWidget* widget, G_GNUC_UNUSED GdkEvent *event, gsvWindow* Win)
 {
 	delete Win;
 	return false;
 }
 
-static void on_file_open (GtkWidget *widget, gsvWindow* Win)
+static void on_file_open (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* Win)
 {
 	Win->OnFileOpen ();
 }
 
-static void on_file_save_as_image(GtkWidget* widget, gsvWindow* Win)
+static void on_file_save_as_image(G_GNUC_UNUSED GtkWidget* widget, gsvWindow* Win)
 {
 	Win->GetApp ()->OnSaveAsImage (Win->GetDoc ());
 }
 
-static void on_file_close (GtkWidget *widget, gsvWindow* Win)
+static void on_file_close (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* Win)
 {
 	Win->OnFileClose ();
 }
 
-static void on_page_setup (GtkWidget *widget, gsvWindow* Win)
+static void on_page_setup (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* Win)
 {
 	Win->OnPageSetup ();
 }
 
-static void on_print_preview (GtkWidget *widget, gsvWindow* Win)
+static void on_print_preview (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* Win)
 {
-	Win->OnFilePrint (true);
+	Win->GetDoc ()->Print (true);
 }
 
-static void on_file_print (GtkWidget *widget, gsvWindow* Win)
+static void on_file_print (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* Win)
 {
-	Win->OnFilePrint (false);
+	Win->GetDoc ()->Print (false);
 }
 
-static void on_quit (GtkWidget *widget, gsvWindow* Win)
+static void on_quit (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* Win)
 {
 	gsvApplication *App = Win->GetApp ();
 	App->OnQuit ();
 }
 
-static void on_copy (GtkWidget* widget, gsvWindow* Win)
+static void on_copy (G_GNUC_UNUSED GtkWidget* widget, gsvWindow* Win)
 {
 	Win->OnCopy ();
 }
 
-static void on_help (GtkWidget *widget, gsvWindow* window)
+static void on_help (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
 {
 	window->GetApp ()->OnHelp ();
 }
 
-static void on_web (GtkWidget *widget, gsvWindow* window)
+static void on_web (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
 {
 	window->GetApp ()->OnWeb ();
 }
 
-static void on_mail (GtkWidget *widget, gsvWindow* window)
+static void on_live_assistance (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
+{
+	Win->GetApp ()->OnLiveAssistance ();
+}
+
+static void on_mail (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
 {
 	window->GetApp ()->OnMail ();
 }
 
-static void on_bug (GtkWidget *widget, gsvWindow* window)
+static void on_bug (G_GNUC_UNUSED GtkWidget *widget, gsvWindow* window)
 {
 	window->GetApp ()->OnBug ();
 }
 
-static void on_about_activate_url (GtkAboutDialog *about, const gchar *url, gpointer data)
+static void on_about_activate_url (G_GNUC_UNUSED GtkAboutDialog *about, const gchar *url, gpointer data)
 {
-	GnomeVFSResult error = gnome_vfs_url_show(url);
-	if (error != GNOME_VFS_OK) {
-		g_print("GnomeVFSResult while trying to launch URL in about dialog: error %u\n", error);
-	}
+	reinterpret_cast <gsvWindow *> (data)->GetApp ()->OnWeb (url);
 }
 
-static void on_about (GtkWidget *widget, void *data)
+static void on_about (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
 {
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GSpectrum is a spectrum viewer for Gnome");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2007 Jean Bréfort\n");
+	const gchar * copyright = _("Copyright © 2007-2008 Jean Bréfort\n");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -137,7 +131,7 @@ static void on_about (GtkWidget *widget, void *data)
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1307\n"
 		"USA";
 	
-	gtk_about_dialog_set_url_hook(on_about_activate_url, NULL, NULL);
+	gtk_about_dialog_set_url_hook (on_about_activate_url, Win, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -161,8 +155,45 @@ static void on_recent (GtkRecentChooser *widget, gsvWindow *Win)
 	gtk_recent_info_unref(info);
 }
 
+
+static bool on_motion (GOGraphWidget *widget, GdkEventMotion *event, G_GNUC_UNUSED gpointer data)
+{
+	GogChart *chart = go_graph_widget_get_chart (widget);
+	GogRenderer *rend = go_graph_widget_get_renderer (widget);
+	GogView *graph_view;
+	GogAxis *x_axis, *y_axis;
+	g_object_get (G_OBJECT (rend), "view", &graph_view, NULL);
+	GSList *l = gog_object_get_children (GOG_OBJECT (chart), gog_object_find_role_by_name (GOG_OBJECT (chart), "Plot"));
+	GogPlot *plot = reinterpret_cast <GogPlot *> (l->data);
+	g_slist_free (l);
+	GogView *view = gog_view_find_child_view (graph_view, GOG_OBJECT (plot));
+	l = gog_chart_get_axes (chart, GOG_AXIS_X);
+	x_axis = GOG_AXIS (l->data);
+	g_slist_free (l);
+	l = gog_chart_get_axes (chart, GOG_AXIS_Y);
+	y_axis = GOG_AXIS (l->data);
+	g_slist_free (l);
+    GogChartMap *map = gog_chart_map_new (chart,
+            &(view->allocation), x_axis, y_axis, NULL, FALSE);
+	if (gog_chart_map_is_valid (map) &&
+			event->x >= view->allocation.x && event->x < view->allocation.x + view->allocation.w &&
+			event->y >= view->allocation.y && event->y < view->allocation.y + view->allocation.h) {
+		GogAxisMap *x_map = gog_chart_map_get_axis_map (map, 0);
+		GogAxisMap *y_map = gog_chart_map_get_axis_map (map, 1);
+		double x = gog_axis_map_from_view (x_map, event->x);
+		double y = gog_axis_map_from_view (y_map, event->y);
+		char *buf = g_strdup_printf ("x=%g y=%g", x, y);
+		gtk_widget_set_tooltip_text (GTK_WIDGET (widget), buf);
+		g_free (buf);
+		gog_chart_map_free (map);
+	} else
+		gtk_widget_set_tooltip_text (GTK_WIDGET (widget), "");
+	g_object_unref (G_OBJECT (graph_view));
+	return true;
+}
+
 static GtkActionEntry entries[] = {
-  { "FileMenu", NULL, N_("_File") },
+  { "FileMenu", NULL, N_("_File"), NULL, NULL, NULL },
 	  { "Open", GTK_STOCK_OPEN, N_("_Open..."), "<control>O",
 		  N_("Open a file"), G_CALLBACK (on_file_open) },
 	  { "SaveAsImage", GTK_STOCK_SAVE_AS, N_("Save As _Image..."), "<control>I",
@@ -177,14 +208,16 @@ static GtkActionEntry entries[] = {
 		  N_("Close the current file"), G_CALLBACK (on_file_close) },
  	  { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
 		  N_("Quit GSpectrum"), G_CALLBACK (on_quit) },
-  { "EditMenu", NULL, N_("_Edit") },
+  { "EditMenu", NULL, N_("_Edit"), NULL, NULL, NULL },
 	  { "Copy", GTK_STOCK_COPY, N_("_Copy"), "<control>C",
 		  N_("Copy the selection"), G_CALLBACK (on_copy) },
-  { "HelpMenu", NULL, N_("_Help") },
+  { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 	  { "Help", GTK_STOCK_HELP, N_("_Contents"), "F1",
-		  N_("View help for the Spetra Viewer"), G_CALLBACK (on_help) },
+		  N_("View help for the Spectra Viewer"), G_CALLBACK (on_help) },
 	  { "Web", NULL, N_("Gnome Chemistry Utils on the _web"), NULL,
 		  N_("Browse the Gnome Chemistry Utils's web site"), G_CALLBACK (on_web) },
+	  { "LiveAssistance", NULL, N_("Live assistance"), NULL,
+		  N_("Open the Gnome Chemistry Utils IRC channel"), G_CALLBACK (on_live_assistance) },
 	  { "Mail", NULL, N_("_Ask a question"), NULL,
 		  N_("Ask a question about the Gnome Chemistry Utils"), G_CALLBACK (on_mail) },
 	  { "Bug", NULL, N_("Report _Bugs"), NULL,
@@ -212,39 +245,15 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
-"      <placeholder name='mail'/>"
-"      <placeholder name='web'/>"
-"      <placeholder name='bug'/>"
+"      <menuitem action='Mail'/>"
+"      <menuitem action='Web'/>"
+"      <menuitem action='LiveAssistance'/>"
+"      <menuitem action='Bug'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
 "</ui>";
 
-static const char *ui_mail_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='mail'>"
-"        <menuitem action='Mail'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static const char *ui_web_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='web'>"
-"        <menuitem action='Web'/>"
-"      </placeholder>"
-"      <placeholder name='bug'>"
-"        <menuitem action='Bug'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
 gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 {
 	m_App = App;
@@ -268,16 +277,9 @@ gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 		g_error_free (error);
 		exit (EXIT_FAILURE);
 	}
-	if (App->HasWebBrowser () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_web_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
-	if (App->HasMailAgent () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_mail_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
 	GtkWidget *menu = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/FileMenu/Open");
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
+	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
 	gtk_recent_filter_add_mime_type (filter, "chemical/x-jcamp-dx");
 	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
@@ -290,11 +292,12 @@ gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
 	m_View = dynamic_cast<gsvView *> (m_Doc->GetView ());
 	m_View->SetWindow (this);
-	gtk_container_add (GTK_CONTAINER (vbox), m_View->GetWidget ());
+	gtk_box_pack_start (GTK_BOX (vbox), m_View->GetOptionBox (), FALSE, FALSE, 0);
+	w = m_View->GetWidget ();
+	g_signal_connect (G_OBJECT (w), "motion-notify-event", G_CALLBACK (on_motion), NULL);
+	gtk_container_add (GTK_CONTAINER (vbox), w);
 	gtk_widget_show_all (GTK_WIDGET (m_Window));
 	// Initialize print settings
-	m_PageSetup = gtk_page_setup_new ();
-	m_PrintSettings = gtk_print_settings_new ();
 }
 
 gsvWindow::~gsvWindow ()
@@ -315,62 +318,7 @@ void gsvWindow::OnFileClose ()
 
 void gsvWindow::OnPageSetup ()
 {
-	GtkPageSetup *setup = gtk_print_run_page_setup_dialog (
-											m_Window,
-											m_PageSetup,
-											m_PrintSettings
-										);
-	g_object_unref (m_PageSetup);
-	m_PageSetup = setup;
-}
-
-static void begin_print (GtkPrintOperation *print, GtkPrintContext *context, gpointer data)
-{
-	gtk_print_operation_set_n_pages (print, 1);
-}
-
-static void draw_page (GtkPrintOperation *print, GtkPrintContext *context, gint page_nr,gpointer data)
-{
-	((gsvWindow *) data)->DoPrint (print, context);
-}
-
-void gsvWindow::OnFilePrint (bool preview)
-{
-	GtkPrintOperation *print;
-	GtkPrintOperationResult res;
-
-	print = gtk_print_operation_new ();
-	gtk_print_operation_set_use_full_page (print, false);
-
-    gtk_print_operation_set_print_settings (print, m_PrintSettings);
-    gtk_print_operation_set_default_page_setup (print, m_PageSetup);
-
-	g_signal_connect (print, "begin_print", G_CALLBACK (begin_print), NULL);
-	g_signal_connect (print, "draw_page", G_CALLBACK (draw_page), this);
-	
-	res = gtk_print_operation_run (print,
-								   (preview)? GTK_PRINT_OPERATION_ACTION_PREVIEW:
-								   GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
-								   m_Window, NULL);
-
-	if (res == GTK_PRINT_OPERATION_RESULT_APPLY) {
-		if (m_PrintSettings != NULL)
-			g_object_unref (m_PrintSettings);
-		m_PrintSettings = GTK_PRINT_SETTINGS (g_object_ref (gtk_print_operation_get_print_settings (print)));
-	}
-
-	g_object_unref (print);
-}
-
-void gsvWindow::DoPrint (GtkPrintOperation *print, GtkPrintContext *context)
-{
-	cairo_t *cr;
-	gdouble width, height;
-
-	cr = gtk_print_context_get_cairo_context (context);
-	width = gtk_print_context_get_width (context);
-	height = gtk_print_context_get_height (context);
-	gog_graph_render_to_cairo (go_graph_widget_get_graph (GO_GRAPH_WIDGET (m_View->GetWidget ())), cr, width, height);
+	new gcu::PrintSetupDlg (m_App, m_Doc);
 }
 
 static GtkTargetEntry const targets[] = {
@@ -380,7 +328,7 @@ static GtkTargetEntry const targets[] = {
 	{(char *) "image/png", 0, 3}
 };
 
-static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_data,  guint info, GogGraph *graph)
+static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData *selection_data,  guint info, GogGraph *graph)
 {
 	guchar *buffer = NULL;
 	char *format = NULL;
@@ -404,7 +352,7 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 			go_locale_untranslated_booleans ();
 		
 			xout = gsf_xml_out_new (output);
-			gog_object_write_xml_sax (GOG_OBJECT (graph), xout);
+			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
 			g_object_unref (xout);
 		
 			/* go_setlocale restores bools to locale translation */
@@ -435,7 +383,7 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 		g_object_unref (output);
 		g_free (format);
 		gtk_selection_data_set (selection_data,
-					selection_data->target, 8,
+					gtk_selection_data_get_target (selection_data), 8,
 					(guchar *) buffer, osize);
 		g_free (buffer);
 	}
